>From fe871317ac6bf8e6457fa3629286952636b26ce0 Mon Sep 17 00:00:00 2001
From: =?utf-8?q?Cyril=20Math=C3=A9?= <cmathe@actech-innovation.com>
Date: Tue, 26 May 2009 10:37:59 +0200
Subject: [PATCH] libvlc API: Add Marquee Filter to libvlc in video.c

  - libvlc_video_enable_marquee     : enable or disable marquee filter
  - libvlc_video_set_marquee_option : set marquee options: color, size...
---
 include/vlc/libvlc_media_player.h |   23 +++++++++++
 src/control/video.c               |   78 +++++++++++++++++++++++++++++++++++++
 src/libvlc.sym                    |    2 +
 3 files changed, 103 insertions(+), 0 deletions(-)

diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index 4b811a0..6cef522 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -726,6 +726,29 @@ VLC_PUBLIC_API void libvlc_video_set_deinterlace( libvlc_media_player_t *,
                                                   int , const char *,
                                                   libvlc_exception_t *);
 
+/**
+ * Enable or disable marquee video filter
+ *
+ * \param p_mi libvlc media player
+ * \param b_enable boolean to enable or disable marquee
+ * \param p_e an initialized exception pointer
+ */
+VLC_PUBLIC_API void libvlc_video_set_marquee( libvlc_media_player_t *,
+                                              int, libvlc_exception_t *);
+
+/**
+ * Set an option to marquee video filter
+ *
+ * \param p_mi libvlc media player
+ * \param psz_option option to set in marquee
+ * \param psz_text add a new text
+ * \param i_val option property
+ * \param p_e an initialized exception pointer
+ */
+VLC_PUBLIC_API void libvlc_video_set_marquee_option( libvlc_media_player_t *,
+                                                     const char *, const char *,
+                                                     int, libvlc_exception_t *);
+
 /** @} video */
 
 /** \defgroup libvlc_audio libvlc_audio
diff --git a/src/control/video.c b/src/control/video.c
index 3b8fbf2..b9e4cf7 100644
--- a/src/control/video.c
+++ b/src/control/video.c
@@ -32,6 +32,7 @@
 #include <vlc_common.h>
 #include <vlc_input.h>
 #include <vlc_vout.h>
+#include <vlc_osd.h>
 
 #include "media_player_internal.h"
 
@@ -628,3 +629,80 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi, int b_enable,
 
     vlc_object_release( p_vout );
 }
+
+/*****************************************************************************
+ * libvlc_video_enable_marquee : enable or disable marquee filter
+ *****************************************************************************/
+void libvlc_video_set_marquee( libvlc_media_player_t *p_mi, int b_enable,
+                               libvlc_exception_t *p_e)
+{
+    vout_thread_t *p_vout = GetVout( p_mi, p_e );
+
+    if( !p_vout )
+    {
+        libvlc_exception_raise( p_e, "Unable to get video output" );
+        return;
+    }
+
+    if( b_enable )
+    {
+        /* enable marquee filter */
+        vout_EnableFilter(p_vout, "marq", true, false);
+    }
+    else
+    {
+        /* disable marquee filter */
+        vout_EnableFilter(p_vout, "marq", false, false);
+    }
+
+    vlc_object_release( p_vout );
+}
+
+/*****************************************************************************
+ * libvlc_video_marquee_set_option : set marquee options : color, size...
+ *****************************************************************************/
+void libvlc_video_set_marquee_option( libvlc_media_player_t *p_mi,
+                                      const char *psz_option,
+                                      const char *psz_text,
+                                      int i_val, libvlc_exception_t *p_e )
+{
+    vout_thread_t *p_vout = GetVout( p_mi, p_e );
+
+    if( !p_vout )
+    {
+        libvlc_exception_raise( p_e, "Unable to get video output" );
+        return;
+    }
+
+    /* get the vlc_object_t corresponding to the option choosen */
+    vlc_object_t *p_marq = ( vlc_object_t * )
+        vlc_object_find_name( p_vout, "marq", FIND_CHILD );
+
+    if( !p_marq )
+    {
+        libvlc_exception_raise( p_e, "Unable to get marq object" );
+        return;
+    }
+
+    /* get the type of var to set */
+    int i_type = var_Type( p_marq, psz_option ) & 0xf0;
+
+    if( i_type == VLC_VAR_STRING )
+    {
+        if( psz_text != NULL )
+            var_SetString(p_marq, psz_option, psz_text);
+        else
+            libvlc_exception_raise( p_e, "No text given" );
+    }
+    else if( i_type == VLC_VAR_INTEGER )
+    {
+        var_SetInteger(p_marq, psz_option, i_val);
+    }
+    else
+    {
+        libvlc_exception_raise( p_e, "Bad type request" );
+    }
+
+    vlc_object_release( p_marq );
+    vlc_object_release( p_vout );
+}
diff --git a/src/libvlc.sym b/src/libvlc.sym
index b8ae128..d56439d 100644
--- a/src/libvlc.sym
+++ b/src/libvlc.sym
@@ -192,6 +192,8 @@ libvlc_video_get_width
 libvlc_video_set_aspect_ratio
 libvlc_video_set_crop_geometry
 libvlc_video_set_deinterlace
+libvlc_video_set_marquee
+libvlc_video_set_marquee_option
 libvlc_video_set_scale
 libvlc_video_set_spu
 libvlc_video_set_subtitle_file
-- 
1.5.4.3

